%HEADER%
%AS-HEADER-FAT%
#
mkdir $TMPDIR/$$
cd $TMPDIR/$$
#
# General Paths
#
S2DVERIF_DIR=%PATHS2DVERIF%
#
# Experiment description
#
EXPID=%EXPID%
CHUNKSIZE=%CHUNKSIZE%
NUMCHUNKS=%NUMCHUNKS%
START_date=%SDATE%
DATELIST="%DATELIST%"
IFSGRID=%IFS_resolution%
NEMGRID=%NEMO_resolution%
#
# Define a few addional variables
#
TEMPLATE=%TEMPLATE_NAME%
MODEL=${TEMPLATE/3}
case $MODEL in
  'ECEARTH' ) 
    lstvars1d=( 'sie' 'sia' 'siv' 'tos' 'tas' 'prlr' 'ohc' 'lohc' 'mohc' 'uohc' 'amoc' ) 
    numfiles=`ls /cfunas/exp/ecearth/${EXPID}/monthly_mean/tas_*/*fc* | wc -l`
    ;;
  'IFS') lstvars1d=( 'tos' 'tas' 'prlr' ) 
    numfiles=`ls /cfunas/exp/ecearth/${EXPID}/monthly_mean/tas_*/*fc* | wc -l`
    ;;
  'NEMO') 
    lstvars1d=( 'sie' 'sia' 'siv' 'ohc' 'lohc' 'mohc' 'uohc' 'amoc' ) 
    numfiles=`ls /cfunas/exp/ecearth/${EXPID}/monthly_mean/heatc/heatc* | wc -l`
    ;;
esac
NLTIMES=$(($NUMCHUNKS * $CHUNKSIZE))
START_month=$(echo $START_date | cut -c5-6)
YEAR0=${DATELIST:0:4}
YEARF=${DATELIST:$((${#DATELIST}-8)):4}
if [[ $YEAR0 -gt $YEARF ]] ; then YEAR0=$YEARF ; YEARF=${DATELIST:0:4} ; fi
INTSDATES=$((${DATELIST:9:4}-$YEAR0))
if [[ $INTSDATES -lt 0 ]] ; then INTSDATES=$((-1*$INTSDATES)) ; fi
if [[ $NLTIMES -le 6 ]] ; then
  RUNMEANLEN=1
elif [[ $NLTIMES -le 12 ]] ; then
  RUNMEANLEN=3
else
  RUNMEANLEN=12
fi
if [[ $MODEL == 'ECEARTH' ]] || [[ $MODEL == 'IFS' ]] ; then 
  case ${IFSGRID} in
   'T159L62') GRID='320x160' ;;
   'T255L91'|'T255L62') GRID='512x256' ;;
   'T511L91') GRID='1024x512' ;;
   'T799L62'|'T799L91') echo "Is the mask ready for this configuration?" ; stop ;;
  esac
fi
VERTNEM=L$(echo ${NEMGRID} | sed 's:ORCA\([0-9]*\)L\([0-9]*\):\2:')
if [[ $VERTNEM == 'LORCA1' ]] ; then VERTNEM='L42' ; fi
#
# Modify the arguments of plot_timeseries
#
cp ${S2DVERIF_DIR}/inst/doc/plot_timeseries.R .
sed -e "s/^lstexpid.*/lstexpid\ \<-\ c\(\'${EXPID}\'\)/1" plot_timeseries.R > tmp1
sed -e "s/^nltimemax.*/nltimemax\ \<-\ ${NLTIMES}/1" tmp1 > tmp2
sed -e "s/^nltimeout.*/nltimeout\ \<-\ ${NLTIMES}/1" tmp2 > tmp3
sed -e "s/^mon0.*/mon0\ \<-\ ${START_month}/1" tmp3 > tmp4
sed -e "s/^year0.*/year0\ \<-\ ${YEAR0}/1" tmp4 > tmp5
sed -e "s/^yearf.*/yearf\ \<-\ ${YEARF}/1" tmp5 > tmp6
sed -e "s/^intsdate.*/intsdate\ \<-\ ${INTSDATES}/1" tmp6 > tmp7
sed -e "s/^runmeanlen.*/runmeanlen\ \<-\ ${RUNMEANLEN}/1" tmp7 > plot_timeseries.R
rm -f tmp1 tmp2 tmp3 tmp4 tmp5 tmp6 tmp7
if [[ $MODEL == 'ECEARTH' ]] || [[ $MODEL == 'IFS' ]] ; then
  sed -e "s/^grid.*/grid\ \<-\ '${GRID}'/1" plot_timeseries.R > tmp1
  rm -f plot_timeseries.R
  mv tmp1 plot_timeseries.R
fi 
if [[ $MODEL == 'ECEARTH' ]] || [[ $MODEL == 'NEMO' ]] ; then
  sed -e "s/^vertnem.*/vertnem\ \<-\ '${VERTNEM}'/1" plot_timeseries.R > tmp1
  rm -f plot_timeseries.R
  mv tmp1 plot_timeseries.R
fi
if [[ $numfiles -le 3 ]] ; then
  sed -e "s/^comptrend.*/comptrend\ \<-\ F/1" plot_timeseries.R > tmp1
  sed -e "s/^compcor.*/compcor\ \<-\ F/1" tmp1 > tmp2
  sed -e "s/^comprms.*/comprms\ \<-\ F/1" tmp2 > tmp3
  sed -e "s/^compspread.*/compspread\ \<-\ F/1" tmp3 > tmp4
  sed -e "s/^plotano.*/plotano\ \<-\ F/1" tmp4 > plot_timeseries.R
  rm -f tmp1 tmp2 tmp3 tmp4 tmp5
fi
chmod +x plot_timeseries.R
#
# Prepare the latex file to gather all figures in a pdf
#
cat > timeseries_${EXPID}.tex <<EOF1
\documentclass[a4paper,12pt]{article}
\usepackage{graphicx,graphics}
\usepackage{array,multirow} 
\pagestyle{empty}
\begin{document}

EOF1

function include_tab_series {
  filename=$1
  cat >> timeseries_${EXPID}.tex <<EOF2
\begin{figure}[t]
\begin{center}
\begin{tabular}{c c}
\includegraphics[width=5cm,height=7cm,angle=-90]{${filename}.eps} & \includegraphics[width=5cm,height=7cm,angle=-90]{${filename}_smoothed.eps}
\end{tabular}
\end{center}
\end{figure}
EOF2
#
# Launch the timeseries plotting
#
for var in ${lstvars1d[@]} ; do
  case $var in
    'sie'|'sia') 
      ./plot_timeseries.R $var N &> plot_timeseries.Rout
      include_tab_series ${var}_${EXPID}_N
      ./plot_timeseries.R $var S &>> plot_timeseries.Rout
      include_tab_series ${var}_${EXPID}_S 
     ;;
    'siv') 
      ./plot_timeseries.R $var N &> plot_timeseries.Rout 
      include_tab_series ${var}_${EXPID}_N
     ;;
    *) ./plot_timeseries.R $var &> plot_timeseries.Rout
     include_tab_series ${var}_${EXPID} 
     ;; 
  esac
  cat plot_timeseries.Rout
  rm -f plot_timeseries.Rout
done
#
# Build the pdf gathering all timeseries
#
latex timeseries_${EXPID}.tex 
dvips -RO timeseries_${EXPID}.dvi -o timeseries_${EXPID}.eps
ps2dpf timeseries_${EXPID}.eps
cp -f timeseries_${EXPID}.pdf /cfu/autosubmit/i06x/plot/.
#
#
# Launch the maps plotting
#
#rm -rf $TMPDIR/$$
#
%AS-TAILER-FAT%

